@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2017-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2017-2023 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -11,9 +11,7 @@ AbstractImapSettingsPassword::AbstractImapSettingsPassword(QObject *parent)
 {
 }
 
-AbstractImapSettingsPassword::~AbstractImapSettingsPassword()
-{
-}
+AbstractImapSettingsPassword::~AbstractImapSettingsPassword() = default;
 
 void AbstractImapSettingsPassword::importPasswords(const SieveEditorUtil::SieveServerConfig &config, const QString &filename, bool reuseImapSettings)
 {
