@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2016-2022 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2016-2023 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -118,7 +118,7 @@ void ImportImapSettingsAkonadiCheckJob::importSettings(const QString &directory,
         if (reuseImapSettings) {
             config.sieveSettings.serverName = imapServerName;
             config.sieveSettings.userName = userName;
-            config.sieveSettings.authenticationType = static_cast<MailTransport::Transport::EnumAuthenticationType::type>(
+            config.sieveSettings.authenticationType = static_cast<MailTransport::Transport::EnumAuthenticationType>(
                 sieveGroup.readEntry(QStringLiteral("Authentication"), static_cast<int>(MailTransport::Transport::EnumAuthenticationType::PLAIN)));
         } else {
             const QString sieveCustomUserName = sieveGroup.readEntry(QStringLiteral("SieveCustomUsername"));
