@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2013-2022 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2023 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -18,8 +18,12 @@
 #include <QTextStream>
 #ifdef WITH_KUSERFEEDBACK
 #include "userfeedback/userfeedbackmanager.h"
+#ifdef USE_KUSERFEEDBACK_QT6
+#include <KUserFeedbackQt6/Provider>
+#else
 #include <KUserFeedback/Provider>
 #endif
+#endif
 
 int main(int argc, char **argv)
 {
@@ -44,7 +48,7 @@ int main(int argc, char **argv)
                          QStringLiteral(SIEVEEDITOR_VERSION),
                          i18n("Sieve Editor"),
                          KAboutLicense::GPL_V2,
-                         i18n("Copyright © 2013-%1 sieveeditor authors", QStringLiteral("2022")));
+                         i18n("Copyright © 2013-%1 sieveeditor authors", QStringLiteral("2023")));
     aboutData.addAuthor(i18n("Laurent Montel"), i18n("Maintainer"), QStringLiteral("montel@kde.org"));
 
     QApplication::setWindowIcon(QIcon::fromTheme(QStringLiteral("kmail")));
