@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2013-2022 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2023 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -21,7 +21,6 @@
 #include <QApplication>
 #include <QStackedWidget>
 #include <QTabBar>
-#include <kwidgetsaddons_version.h>
 
 namespace
 {
@@ -606,21 +605,13 @@ void SieveEditorMainWidget::slotTabCloseRequested(int index)
     auto page = qobject_cast<SieveEditorPageWidget *>(mTabWidget->widget(index));
     if (page) {
         if (page->isModified()) {
-#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
             const int result = KMessageBox::questionTwoActionsCancel(this,
-#else
-            const int result = KMessageBox::questionYesNoCancel(this,
-#endif
                                                                      i18n("Script was modified. Do you want to save before closing?"),
                                                                      i18n("Close script"),
                                                                      KStandardGuiItem::save(),
                                                                      KStandardGuiItem::close(),
                                                                      KStandardGuiItem::cancel());
-#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
             if (result == KMessageBox::ButtonCode::PrimaryAction) {
-#else
-            if (result == KMessageBox::Yes) {
-#endif
                 if (page->uploadScriptAndCloseTab(index)) {
                     return;
                 }
