@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2013-2022 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2023 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -39,9 +39,17 @@
 #include <QToolButton>
 #ifdef WITH_KUSERFEEDBACK
 #include "userfeedback/userfeedbackmanager.h"
+#ifdef USE_KUSERFEEDBACK_QT6
+#include <KUserFeedbackQt6/NotificationPopup>
+#include <KUserFeedbackQt6/Provider>
+#else
 #include <KUserFeedback/NotificationPopup>
 #include <KUserFeedback/Provider>
 #endif
+#endif
+
+#include <KWindowConfig>
+#include <QWindow>
 
 namespace
 {
@@ -84,9 +92,23 @@ SieveEditorMainWindow::SieveEditorMainWindow(QWidget *parent)
 
 SieveEditorMainWindow::~SieveEditorMainWindow()
 {
-    KSharedConfig::Ptr config = KSharedConfig::openStateConfig();
-    KConfigGroup group = config->group(mySieveEditorMainWindowConfigGroupName);
-    group.writeEntry("Size", size());
+    writeConfig();
+}
+
+void SieveEditorMainWindow::readConfig()
+{
+    create(); // ensure a window is created
+    windowHandle()->resize(QSize(800, 600));
+    KConfigGroup group(KSharedConfig::openStateConfig(), mySieveEditorMainWindowConfigGroupName);
+    KWindowConfig::restoreWindowSize(windowHandle(), group);
+    resize(windowHandle()->size()); // workaround for QTBUG-40584
+}
+
+void SieveEditorMainWindow::writeConfig()
+{
+    KConfigGroup group(KSharedConfig::openStateConfig(), mySieveEditorMainWindowConfigGroupName);
+    KWindowConfig::saveWindowSize(windowHandle(), group);
+    group.sync();
 }
 
 void SieveEditorMainWindow::initStatusBar()
@@ -115,16 +137,6 @@ void SieveEditorMainWindow::slotUpdateButtons(bool newScriptAction, bool editScr
     mDesactivateScript->setEnabled(desactivateScriptAction);
 }
 
-void SieveEditorMainWindow::readConfig()
-{
-    KSharedConfig::Ptr config = KSharedConfig::openStateConfig();
-    KConfigGroup group = KConfigGroup(config, mySieveEditorMainWindowConfigGroupName);
-    const QSize sizeDialog = group.readEntry("Size", QSize(800, 600));
-    if (sizeDialog.isValid()) {
-        resize(sizeDialog);
-    }
-}
-
 void SieveEditorMainWindow::setupActions()
 {
     KActionCollection *ac = actionCollection();
